@@ -52,45 +52,47 @@
 
 #include <QCoreApplication>
 
-QT_USE_NAMESPACE
-
-SerialPortWriter::SerialPortWriter(QSerialPort *serialPort, QObject *parent)
-    : QObject(parent)
-    , m_serialPort(serialPort)
-    , m_standardOutput(stdout)
-    , m_bytesWritten(0)
+SerialPortWriter::SerialPortWriter(QSerialPort *serialPort, QObject *parent) :
+    QObject(parent),
+    m_serialPort(serialPort),
+    m_standardOutput(stdout)
 {
     m_timer.setSingleShot(true);
-    connect(m_serialPort, &QSerialPort::bytesWritten, this, &SerialPortWriter::handleBytesWritten);
-    connect(m_serialPort, static_cast<void (QSerialPort::*)(QSerialPort::SerialPortError)>(&QSerialPort::error),
+    connect(m_serialPort, &QSerialPort::bytesWritten,
+            this, &SerialPortWriter::handleBytesWritten);
+    connect(m_serialPort, &QSerialPort::errorOccurred,
             this, &SerialPortWriter::handleError);
     connect(&m_timer, &QTimer::timeout, this, &SerialPortWriter::handleTimeout);
 }
 
-SerialPortWriter::~SerialPortWriter()
-{
-}
-
 void SerialPortWriter::handleBytesWritten(qint64 bytes)
 {
     m_bytesWritten += bytes;
     if (m_bytesWritten == m_writeData.size()) {
         m_bytesWritten = 0;
-        m_standardOutput << QObject::tr("Data successfully sent to port %1").arg(m_serialPort->portName()) << endl;
+        m_standardOutput << QObject::tr("Data successfully sent to port %1")
+                            .arg(m_serialPort->portName()) << "\n";
         QCoreApplication::quit();
     }
 }
 
 void SerialPortWriter::handleTimeout()
 {
-    m_standardOutput << QObject::tr("Operation timed out for port %1, error: %2").arg(m_serialPort->portName()).arg(m_serialPort->errorString()) << endl;
+    m_standardOutput << QObject::tr("Operation timed out for port %1, error: %2")
+                        .arg(m_serialPort->portName())
+                        .arg(m_serialPort->errorString())
+                     << "\n";
     QCoreApplication::exit(1);
 }
 
 void SerialPortWriter::handleError(QSerialPort::SerialPortError serialPortError)
 {
     if (serialPortError == QSerialPort::WriteError) {
-        m_standardOutput << QObject::tr("An I/O error occurred while writing the data to port %1, error: %2").arg(m_serialPort->portName()).arg(m_serialPort->errorString()) << endl;
+        m_standardOutput << QObject::tr("An I/O error occurred while writing"
+                                        " the data to port %1, error: %2")
+                            .arg(m_serialPort->portName())
+                            .arg(m_serialPort->errorString())
+                         << "\n";
         QCoreApplication::exit(1);
     }
 }
@@ -99,13 +101,19 @@ void SerialPortWriter::write(const QByteArray &writeData)
 {
     m_writeData = writeData;
 
-    qint64 bytesWritten = m_serialPort->write(writeData);
+    const qint64 bytesWritten = m_serialPort->write(writeData);
 
     if (bytesWritten == -1) {
-        m_standardOutput << QObject::tr("Failed to write the data to port %1, error: %2").arg(m_serialPort->portName()).arg(m_serialPort->errorString()) << endl;
+        m_standardOutput << QObject::tr("Failed to write the data to port %1, error: %2")
+                            .arg(m_serialPort->portName())
+                            .arg(m_serialPort->errorString())
+                         << "\n";
         QCoreApplication::exit(1);
     } else if (bytesWritten != m_writeData.size()) {
-        m_standardOutput << QObject::tr("Failed to write all the data to port %1, error: %2").arg(m_serialPort->portName()).arg(m_serialPort->errorString()) << endl;
+        m_standardOutput << QObject::tr("Failed to write all the data to port %1, error: %2")
+                            .arg(m_serialPort->portName())
+                            .arg(m_serialPort->errorString())
+                         << "\n";
         QCoreApplication::exit(1);
     }
 
